pub struct Recoder;Expand description
RLNC Recoder.
Implementations
Sourceimpl Recoder
impl Recoder
Sourcepub fn recode(
coded: &[CodedPacket],
rng: &mut SimpleRng,
) -> Result<CodedPacket, RlncError>
pub fn recode( coded: &[CodedPacket], rng: &mut SimpleRng, ) -> Result<CodedPacket, RlncError>
Produce a new coded packet from a set of already-coded packets.
All input packets must have the same coefficient length and payload length.